@@ -26,7 +26,7 @@
 //!         let mut env = unsafe { env_builder.open_rw()? };
 //!         let db1 = unsafe { env.create_db(&db1_opts)? };
 //!         let db2 = unsafe { env.create_db(&db2_opts)? };
-//!         let mut txn = env.txn()?;
+//!         let mut txn = env.txn_rw()?;
 //!         txn.put(&db1, "key1".as_bytes(), "value1".as_bytes())?;
 //!         txn.put(&db2, "Prime", &17)?;
 //!         txn.commit()?;
@@ -35,7 +35,7 @@
 //!         let env = unsafe { env_builder.open_ro()? };
 //!         let db1 = unsafe { env.open_db(&db1_opts)? };
 //!         let db2 = unsafe { env.open_db(&db2_opts)? };
-//!         let txn = env.txn()?;
+//!         let txn = env.txn_ro()?;
 //!         assert_eq!(txn.get(&db1, "key1".as_bytes())?, Some("value1".as_bytes()));
 //!         assert_eq!(txn.get_owned(&db2, "Prime")?, Some(17));
 //!     }
@@ -164,7 +164,7 @@ impl Drop for EnvBackend {
 /// An environment can be opened using [`EnvBuilder`].
 ///
 /// Use [`Env::open_db`] to retrieve database handles
-/// and [`EnvRo::txn`] to start a read-only transaction.
+/// and [`Env::txn_ro`] to start a read-only transaction.
 ///
 /// It's possible to clone the handle, in which case the environment will be
 /// closed when the last handle is dropped.
@@ -178,7 +178,7 @@ pub struct EnvRo {
 /// An environment can be opened using [`EnvBuilder`].
 ///
 /// Use [`Env::open_db`] or [`EnvRw::create_db`] to retrieve database handles
-/// and [`EnvRw::txn`] to start a read-write transaction.
+/// and [`EnvRw::txn_rw`] to start a read-write transaction.
 ///
 /// It's possible to create a read-only handle by invoking [`Env::clone_ro`].
 /// The environment is closed when the last handle is dropped.
@@ -235,6 +235,8 @@ impl<'a> Drop for TxnBackend<'a> {
 
 /// Read-only transaction
 ///
+/// A read-only transaction can be started with [`Env::txn_ro`].
+///
 /// The methods for read-only access to the database are accessible through the
 /// [`Txn`] trait (which is implemented by `TxnRo` and [`TxnRw`]).
 ///
@@ -252,6 +254,8 @@ unsafe impl<'a> Sync for TxnRo<'a> {}
 
 /// Read-write transaction
 ///
+/// A read-write transaction can be started with [`EnvRw::txn_rw`].
+///
 /// The methods for read-only access to the database are accessible through the
 /// [`Txn`] trait (which is implemented by [`TxnRo`] and `TxnRw`).
 /// Methods for write access, however, are available directly on the `TxnRw`
@@ -904,9 +908,11 @@ impl<K: ?Sized, V: ?Sized, N> DbOptions<K, V, KeysDuplicate, N> {
 /// Use [`Env::open_db`] to retrieve database handles.
 ///
 /// To modify data inside a database, a transaction is needed which can be
-/// opened with either [`EnvRo::txn`] (read-only) or [`EnvRw::txn`] (for
+/// opened with either [`Env::txn_ro`] (read-only) or [`EnvRw::txn_rw`] (for
 /// reading and writing).
 pub trait Env {
+    /// Start read-only transaction
+    fn txn_ro(&self) -> Result<TxnRo<'_>, io::Error>;
     /// Get new read-only handle for environment
     fn clone_ro(&self) -> EnvRo;
     /// Get maximum size of keys and duplicate data
@@ -962,6 +968,26 @@ where
 }
 
 impl EnvBackend {
+    /// Start read-only transaction
+    fn txn_ro(&self) -> Result<TxnRo<'_>, io::Error> {
+        unsafe {
+            let mut inner_txn = MaybeUninit::<*mut lmdb::MDB_txn>::uninit();
+            check_err_code(lmdb::mdb_txn_begin(
+                self.inner,
+                null_mut(),
+                lmdb::MDB_RDONLY as LmdbFlags,
+                inner_txn.as_mut_ptr(),
+            ))?;
+            let inner_txn = inner_txn.assume_init();
+            Ok(TxnRo {
+                backend: Mutex::new(TxnBackend {
+                    env_backend: &self,
+                    inner: inner_txn,
+                    cursors: Default::default(),
+                }),
+            })
+        }
+    }
     /// Return true if given size (in bytes) is valid for a key (or value in a
     /// database with duplicate keys)
     fn size_valid_keysize(&self, size: usize) -> bool {
@@ -1084,6 +1110,9 @@ impl EnvBackend {
 }
 
 impl Env for EnvRo {
+    fn txn_ro(&self) -> Result<TxnRo<'_>, io::Error> {
+        self.backend.txn_ro()
+    }
     fn clone_ro(&self) -> EnvRo {
         EnvRo {
             backend: self.backend.clone(),
@@ -1117,6 +1146,9 @@ impl Env for EnvRo {
 }
 
 impl Env for EnvRw {
+    fn txn_ro(&self) -> Result<TxnRo<'_>, io::Error> {
+        self.backend.txn_ro()
+    }
     fn clone_ro(&self) -> EnvRo {
         EnvRo {
             backend: self.backend.clone(),
@@ -1149,29 +1181,6 @@ impl Env for EnvRw {
     }
 }
 
-impl EnvRo {
-    /// Start read-only transaction
-    pub fn txn(&self) -> Result<TxnRo<'_>, io::Error> {
-        unsafe {
-            let mut inner = MaybeUninit::<*mut lmdb::MDB_txn>::uninit();
-            check_err_code(lmdb::mdb_txn_begin(
-                self.backend.inner,
-                null_mut(),
-                lmdb::MDB_RDONLY as LmdbFlags,
-                inner.as_mut_ptr(),
-            ))?;
-            let inner = inner.assume_init();
-            Ok(TxnRo {
-                backend: Mutex::new(TxnBackend {
-                    env_backend: &self.backend,
-                    inner,
-                    cursors: Default::default(),
-                }),
-            })
-        }
-    }
-}
-
 impl EnvRw {
     /// Open databases in environment and create if non-existing
     ///
@@ -1240,7 +1249,7 @@ impl EnvRw {
         Ok(())
     }
     /// Start read-write transaction
-    pub fn txn(&mut self) -> Result<TxnRw<'_>, io::Error> {
+    pub fn txn_rw(&mut self) -> Result<TxnRw<'_>, io::Error> {
         unsafe {
             let mut txn_inner = MaybeUninit::<*mut lmdb::MDB_txn>::uninit();
             check_err_code(lmdb::mdb_txn_begin(
